import { ActionHandler } from "./action_handler";
import { BodyWrapper } from "./body_wrapper";
import { RecordActionHandler } from "./record_action_handler";
import { RecordBodyWrapper } from "./record_body_wrapper";
import { RecordResponseHandler } from "./record_response_handler";
import { ResponseHandler } from "./response_handler";
import { Param } from "../../../../../../routes/param";
import { ParameterMap } from "../../../../../../routes/parameter_map";
import { APIResponse } from "../../../../../../routes/controllers/api_response";
declare class ContactRolesOperations {
    /**
     * The method to get contact roles
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getContactRoles(): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to create contact roles
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    createContactRoles(request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to update contact roles
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateContactRoles(request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delete contact roles
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    deleteContactRoles(paramInstance?: ParameterMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to get contact role
     * @param id A bigint representing the id
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getContactRole(id: bigint): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to update contact role
     * @param id A bigint representing the id
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateContactRole(id: bigint, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delete contact role
     * @param id A bigint representing the id
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    deleteContactRole(id: bigint): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to get all contact roles of deal
     * @param dealId A bigint representing the dealId
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<RecordResponseHandler>
     * @throws SDKException
     */
    getAllContactRolesOfDeal(dealId: bigint, paramInstance?: ParameterMap): Promise<APIResponse<RecordResponseHandler>>;
    /**
     * The method to get contact role of deal
     * @param contactId A bigint representing the contactId
     * @param dealId A bigint representing the dealId
     * @returns An instance of APIResponse<RecordResponseHandler>
     * @throws SDKException
     */
    getContactRoleOfDeal(contactId: bigint, dealId: bigint): Promise<APIResponse<RecordResponseHandler>>;
    /**
     * The method to add contact role to deal
     * @param contactId A bigint representing the contactId
     * @param dealId A bigint representing the dealId
     * @param request An instance of RecordBodyWrapper
     * @returns An instance of APIResponse<RecordActionHandler>
     * @throws SDKException
     */
    addContactRoleToDeal(contactId: bigint, dealId: bigint, request: RecordBodyWrapper): Promise<APIResponse<RecordActionHandler>>;
    /**
     * The method to remove contact role from deal
     * @param contactId A bigint representing the contactId
     * @param dealId A bigint representing the dealId
     * @returns An instance of APIResponse<RecordActionHandler>
     * @throws SDKException
     */
    removeContactRoleFromDeal(contactId: bigint, dealId: bigint): Promise<APIResponse<RecordActionHandler>>;
}
declare class DeleteContactRolesParam {
    static IDS: Param<string>;
}
declare class GetAllContactRolesOfDealParam {
    static IDS: Param<string>;
}
export { DeleteContactRolesParam as DeleteContactRolesParam, ContactRolesOperations as MasterModel, ContactRolesOperations as ContactRolesOperations, GetAllContactRolesOfDealParam as GetAllContactRolesOfDealParam };
