"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreatePipelinesParam = exports.UpdatePipelineParam = exports.UpdatePipelinesParam = exports.PipelineOperations = exports.MasterModel = exports.GetPipelinesParam = exports.TransferAndDeleteParam = exports.GetPipelineParam = void 0;
const param_1 = require("../../../../../../routes/param");
const common_api_handler_1 = require("../../../../../../routes/middlewares/common_api_handler");
const constants_1 = require("../../../../../../utils/util/constants");
class PipelineOperations {
    /**
     * Creates an instance of PipelineOperations with the given parameters
     * @param layoutId A bigint representing the layoutId
     */
    constructor(layoutId) {
        this.layoutId = layoutId;
    }
    /**
     * The method to transfer and delete
     * @param request An instance of TransferAndDeleteWrapper
     * @returns An instance of APIResponse<TransferActionHandler>
     * @throws SDKException
     */
    async transferAndDelete(request) {
        let handlerInstance = new common_api_handler_1.CommonAPIHandler();
        let apiPath = '';
        apiPath = apiPath.concat("/crm/v2.1/settings/pipeline/actions/transfer");
        handlerInstance.setAPIPath(apiPath);
        handlerInstance.setHttpMethod(constants_1.Constants.REQUEST_METHOD_POST);
        handlerInstance.setCategoryMethod(constants_1.Constants.REQUEST_CATEGORY_CREATE);
        handlerInstance.setContentType("application/json");
        handlerInstance.setRequest(request);
        handlerInstance.setMandatoryChecker(true);
        await handlerInstance.addParam(new param_1.Param("layout_id", "com.zoho.crm.api.Pipeline.TransferAndDeleteParam"), this.layoutId);
        let TransferActionHandler = require.resolve("./transfer_action_handler");
        return handlerInstance.apiCall(TransferActionHandler, "application/json");
    }
    /**
     * The method to get pipelines
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    async getPipelines() {
        let handlerInstance = new common_api_handler_1.CommonAPIHandler();
        let apiPath = '';
        apiPath = apiPath.concat("/crm/v2.1/settings/pipeline");
        handlerInstance.setAPIPath(apiPath);
        handlerInstance.setHttpMethod(constants_1.Constants.REQUEST_METHOD_GET);
        handlerInstance.setCategoryMethod(constants_1.Constants.REQUEST_CATEGORY_READ);
        await handlerInstance.addParam(new param_1.Param("layout_id", "com.zoho.crm.api.Pipeline.GetPipelinesParam"), this.layoutId);
        let ResponseHandler = require.resolve("./response_handler");
        return handlerInstance.apiCall(ResponseHandler, "application/json");
    }
    /**
     * The method to create pipelines
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    async createPipelines(request) {
        let handlerInstance = new common_api_handler_1.CommonAPIHandler();
        let apiPath = '';
        apiPath = apiPath.concat("/crm/v2.1/settings/pipeline");
        handlerInstance.setAPIPath(apiPath);
        handlerInstance.setHttpMethod(constants_1.Constants.REQUEST_METHOD_POST);
        handlerInstance.setCategoryMethod(constants_1.Constants.REQUEST_CATEGORY_CREATE);
        handlerInstance.setContentType("application/json");
        handlerInstance.setRequest(request);
        handlerInstance.setMandatoryChecker(true);
        await handlerInstance.addParam(new param_1.Param("layout_id", "com.zoho.crm.api.Pipeline.CreatePipelinesParam"), this.layoutId);
        let ActionHandler = require.resolve("./action_handler");
        return handlerInstance.apiCall(ActionHandler, "application/json");
    }
    /**
     * The method to update pipelines
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    async updatePipelines(request) {
        let handlerInstance = new common_api_handler_1.CommonAPIHandler();
        let apiPath = '';
        apiPath = apiPath.concat("/crm/v2.1/settings/pipeline");
        handlerInstance.setAPIPath(apiPath);
        handlerInstance.setHttpMethod(constants_1.Constants.REQUEST_METHOD_PUT);
        handlerInstance.setCategoryMethod(constants_1.Constants.REQUEST_CATEGORY_UPDATE);
        handlerInstance.setContentType("application/json");
        handlerInstance.setRequest(request);
        handlerInstance.setMandatoryChecker(true);
        await handlerInstance.addParam(new param_1.Param("layout_id", "com.zoho.crm.api.Pipeline.UpdatePipelinesParam"), this.layoutId);
        let ActionHandler = require.resolve("./action_handler");
        return handlerInstance.apiCall(ActionHandler, "application/json");
    }
    /**
     * The method to get pipeline
     * @param pipelineId A bigint representing the pipelineId
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    async getPipeline(pipelineId) {
        let handlerInstance = new common_api_handler_1.CommonAPIHandler();
        let apiPath = '';
        apiPath = apiPath.concat("/crm/v2.1/settings/pipeline/");
        apiPath = apiPath.concat(pipelineId.toString());
        handlerInstance.setAPIPath(apiPath);
        handlerInstance.setHttpMethod(constants_1.Constants.REQUEST_METHOD_GET);
        handlerInstance.setCategoryMethod(constants_1.Constants.REQUEST_CATEGORY_READ);
        await handlerInstance.addParam(new param_1.Param("layout_id", "com.zoho.crm.api.Pipeline.GetPipelineParam"), this.layoutId);
        let ResponseHandler = require.resolve("./response_handler");
        return handlerInstance.apiCall(ResponseHandler, "application/json");
    }
    /**
     * The method to update pipeline
     * @param pipelineId A bigint representing the pipelineId
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    async updatePipeline(pipelineId, request) {
        let handlerInstance = new common_api_handler_1.CommonAPIHandler();
        let apiPath = '';
        apiPath = apiPath.concat("/crm/v2.1/settings/pipeline/");
        apiPath = apiPath.concat(pipelineId.toString());
        handlerInstance.setAPIPath(apiPath);
        handlerInstance.setHttpMethod(constants_1.Constants.REQUEST_METHOD_PUT);
        handlerInstance.setCategoryMethod(constants_1.Constants.REQUEST_CATEGORY_UPDATE);
        handlerInstance.setContentType("application/json");
        handlerInstance.setRequest(request);
        await handlerInstance.addParam(new param_1.Param("layout_id", "com.zoho.crm.api.Pipeline.UpdatePipelineParam"), this.layoutId);
        let ActionHandler = require.resolve("./action_handler");
        return handlerInstance.apiCall(ActionHandler, "application/json");
    }
}
exports.MasterModel = PipelineOperations;
exports.PipelineOperations = PipelineOperations;
class TransferAndDeleteParam {
}
exports.TransferAndDeleteParam = TransferAndDeleteParam;
class GetPipelinesParam {
}
exports.GetPipelinesParam = GetPipelinesParam;
class CreatePipelinesParam {
}
exports.CreatePipelinesParam = CreatePipelinesParam;
class UpdatePipelinesParam {
}
exports.UpdatePipelinesParam = UpdatePipelinesParam;
class GetPipelineParam {
}
exports.GetPipelineParam = GetPipelineParam;
class UpdatePipelineParam {
}
exports.UpdatePipelineParam = UpdatePipelineParam;
