import { Header } from "../../../../../../routes/header";
import { HeaderMap } from "../../../../../../routes/header_map";
import { Param } from "../../../../../../routes/param";
import { ParameterMap } from "../../../../../../routes/parameter_map";
import { ActionHandler } from "./action_handler";
import { BodyWrapper } from "./body_wrapper";
import { ConvertActionHandler } from "./convert_action_handler";
import { ConvertBodyWrapper } from "./convert_body_wrapper";
import { CountHandler } from "./count_handler";
import { DeletedRecordsHandler } from "./deleted_records_handler";
import { DownloadHandler } from "./download_handler";
import { FileBodyWrapper } from "./file_body_wrapper";
import { FileHandler } from "./file_handler";
import { MassUpdateActionHandler } from "./mass_update_action_handler";
import { MassUpdateBodyWrapper } from "./mass_update_body_wrapper";
import { MassUpdateResponseHandler } from "./mass_update_response_handler";
import { ResponseHandler } from "./response_handler";
import { APIResponse } from "../../../../../../routes/controllers/api_response";
declare class RecordOperations {
    /**
     * The method to get record
     * @param id A bigint representing the id
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getRecord(id: bigint, moduleAPIName: string, paramInstance?: ParameterMap, headerInstance?: HeaderMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to update record
     * @param id A bigint representing the id
     * @param moduleAPIName A string representing the moduleAPIName
     * @param request An instance of BodyWrapper
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateRecord(id: bigint, moduleAPIName: string, request: BodyWrapper, headerInstance?: HeaderMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delete record
     * @param id A bigint representing the id
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    deleteRecord(id: bigint, moduleAPIName: string, paramInstance?: ParameterMap, headerInstance?: HeaderMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to get records
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getRecords(moduleAPIName: string, paramInstance?: ParameterMap, headerInstance?: HeaderMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to create records
     * @param moduleAPIName A string representing the moduleAPIName
     * @param request An instance of BodyWrapper
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    createRecords(moduleAPIName: string, request: BodyWrapper, headerInstance?: HeaderMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to update records
     * @param moduleAPIName A string representing the moduleAPIName
     * @param request An instance of BodyWrapper
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateRecords(moduleAPIName: string, request: BodyWrapper, headerInstance?: HeaderMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delete records
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    deleteRecords(moduleAPIName: string, paramInstance?: ParameterMap, headerInstance?: HeaderMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to upsert records
     * @param moduleAPIName A string representing the moduleAPIName
     * @param request An instance of BodyWrapper
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    upsertRecords(moduleAPIName: string, request: BodyWrapper, headerInstance?: HeaderMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to get deleted records
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<DeletedRecordsHandler>
     * @throws SDKException
     */
    getDeletedRecords(moduleAPIName: string, paramInstance?: ParameterMap, headerInstance?: HeaderMap): Promise<APIResponse<DeletedRecordsHandler>>;
    /**
     * The method to search records
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    searchRecords(moduleAPIName: string, paramInstance?: ParameterMap, headerInstance?: HeaderMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to convert lead
     * @param id A bigint representing the id
     * @param request An instance of ConvertBodyWrapper
     * @returns An instance of APIResponse<ConvertActionHandler>
     * @throws SDKException
     */
    convertLead(id: bigint, request: ConvertBodyWrapper): Promise<APIResponse<ConvertActionHandler>>;
    /**
     * The method to get photo
     * @param id A bigint representing the id
     * @param moduleAPIName A string representing the moduleAPIName
     * @returns An instance of APIResponse<DownloadHandler>
     * @throws SDKException
     */
    getPhoto(id: bigint, moduleAPIName: string): Promise<APIResponse<DownloadHandler>>;
    /**
     * The method to upload photo
     * @param id A bigint representing the id
     * @param moduleAPIName A string representing the moduleAPIName
     * @param request An instance of FileBodyWrapper
     * @returns An instance of APIResponse<FileHandler>
     * @throws SDKException
     */
    uploadPhoto(id: bigint, moduleAPIName: string, request: FileBodyWrapper): Promise<APIResponse<FileHandler>>;
    /**
     * The method to delete photo
     * @param id A bigint representing the id
     * @param moduleAPIName A string representing the moduleAPIName
     * @returns An instance of APIResponse<FileHandler>
     * @throws SDKException
     */
    deletePhoto(id: bigint, moduleAPIName: string): Promise<APIResponse<FileHandler>>;
    /**
     * The method to mass update records
     * @param moduleAPIName A string representing the moduleAPIName
     * @param request An instance of MassUpdateBodyWrapper
     * @returns An instance of APIResponse<MassUpdateActionHandler>
     * @throws SDKException
     */
    massUpdateRecords(moduleAPIName: string, request: MassUpdateBodyWrapper): Promise<APIResponse<MassUpdateActionHandler>>;
    /**
     * The method to get mass update status
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<MassUpdateResponseHandler>
     * @throws SDKException
     */
    getMassUpdateStatus(moduleAPIName: string, paramInstance?: ParameterMap): Promise<APIResponse<MassUpdateResponseHandler>>;
    /**
     * The method to assign territories to multiple records
     * @param moduleAPIName A string representing the moduleAPIName
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    assignTerritoriesToMultipleRecords(moduleAPIName: string, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to assign territory to record
     * @param moduleAPIName A string representing the moduleAPIName
     * @param id A bigint representing the id
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    assignTerritoryToRecord(moduleAPIName: string, id: bigint, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to remove territories from multiple records
     * @param moduleAPIName A string representing the moduleAPIName
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    removeTerritoriesFromMultipleRecords(moduleAPIName: string, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to remove territories from record
     * @param moduleAPIName A string representing the moduleAPIName
     * @param id A bigint representing the id
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    removeTerritoriesFromRecord(moduleAPIName: string, id: bigint, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to record count
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<CountHandler>
     * @throws SDKException
     */
    recordCount(moduleAPIName: string, paramInstance?: ParameterMap): Promise<APIResponse<CountHandler>>;
    /**
     * The method to get record using external id
     * @param externalFieldValue A string representing the externalFieldValue
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getRecordUsingExternalId(externalFieldValue: string, moduleAPIName: string, paramInstance?: ParameterMap, headerInstance?: HeaderMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to update record using external id
     * @param externalFieldValue A string representing the externalFieldValue
     * @param moduleAPIName A string representing the moduleAPIName
     * @param request An instance of BodyWrapper
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateRecordUsingExternalId(externalFieldValue: string, moduleAPIName: string, request: BodyWrapper, headerInstance?: HeaderMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delete record using external id
     * @param externalFieldValue A string representing the externalFieldValue
     * @param moduleAPIName A string representing the moduleAPIName
     * @param paramInstance An instance of ParameterMap
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    deleteRecordUsingExternalId(externalFieldValue: string, moduleAPIName: string, paramInstance?: ParameterMap, headerInstance?: HeaderMap): Promise<APIResponse<ActionHandler>>;
}
declare class GetRecordParam {
    static APPROVED: Param<string>;
    static CONVERTED: Param<string>;
    static CVID: Param<string>;
    static UID: Param<string>;
    static FIELDS: Param<string>;
    static STARTDATETIME: Param<Date>;
    static ENDDATETIME: Param<Date>;
    static TERRITORY_ID: Param<string>;
    static INCLUDE_CHILD: Param<string>;
}
declare class GetRecordHeader {
    static IF_MODIFIED_SINCE: Header<Date>;
    static X_EXTERNAL: Header<string>;
}
declare class UpdateRecordHeader {
    static X_EXTERNAL: Header<string>;
}
declare class DeleteRecordParam {
    static WF_TRIGGER: Param<boolean>;
}
declare class DeleteRecordHeader {
    static X_EXTERNAL: Header<string>;
}
declare class GetRecordsParam {
    static APPROVED: Param<string>;
    static CONVERTED: Param<string>;
    static CVID: Param<string>;
    static IDS: Param<string>;
    static UID: Param<string>;
    static FIELDS: Param<string>;
    static SORT_BY: Param<string>;
    static SORT_ORDER: Param<string>;
    static PAGE: Param<number>;
    static PER_PAGE: Param<number>;
    static STARTDATETIME: Param<Date>;
    static ENDDATETIME: Param<Date>;
    static TERRITORY_ID: Param<string>;
    static INCLUDE_CHILD: Param<string>;
}
declare class GetRecordsHeader {
    static IF_MODIFIED_SINCE: Header<Date>;
    static X_EXTERNAL: Header<string>;
}
declare class CreateRecordsHeader {
    static X_EXTERNAL: Header<string>;
}
declare class UpdateRecordsHeader {
    static X_EXTERNAL: Header<string>;
}
declare class DeleteRecordsParam {
    static IDS: Param<string>;
    static WF_TRIGGER: Param<boolean>;
}
declare class DeleteRecordsHeader {
    static X_EXTERNAL: Header<string>;
}
declare class UpsertRecordsHeader {
    static X_EXTERNAL: Header<string>;
}
declare class GetDeletedRecordsParam {
    static TYPE: Param<string>;
    static PAGE: Param<number>;
    static PER_PAGE: Param<number>;
}
declare class GetDeletedRecordsHeader {
    static IF_MODIFIED_SINCE: Header<Date>;
}
declare class SearchRecordsParam {
    static CRITERIA: Param<string>;
    static EMAIL: Param<string>;
    static PHONE: Param<string>;
    static WORD: Param<string>;
    static CONVERTED: Param<string>;
    static APPROVED: Param<string>;
    static PAGE: Param<number>;
    static PER_PAGE: Param<number>;
    static FIELDS: Param<string>;
}
declare class SearchRecordsHeader {
    static X_EXTERNAL: Header<string>;
}
declare class GetMassUpdateStatusParam {
    static JOB_ID: Param<string>;
}
declare class RecordCountParam {
    static CRITERIA: Param<string>;
    static EMAIL: Param<string>;
    static PHONE: Param<string>;
    static WORD: Param<string>;
}
declare class GetRecordUsingExternalIDParam {
    static APPROVED: Param<string>;
    static CONVERTED: Param<string>;
    static CVID: Param<string>;
    static UID: Param<string>;
    static FIELDS: Param<string>;
    static STARTDATETIME: Param<Date>;
    static ENDDATETIME: Param<Date>;
    static TERRITORY_ID: Param<string>;
    static INCLUDE_CHILD: Param<string>;
}
declare class GetRecordUsingExternalIDHeader {
    static IF_MODIFIED_SINCE: Header<Date>;
    static X_EXTERNAL: Header<string>;
}
declare class UpdateRecordUsingExternalIDHeader {
    static X_EXTERNAL: Header<string>;
}
declare class DeleteRecordUsingExternalIDParam {
    static WF_TRIGGER: Param<boolean>;
}
declare class DeleteRecordUsingExternalIDHeader {
    static X_EXTERNAL: Header<string>;
}
export { GetRecordParam as GetRecordParam, CreateRecordsHeader as CreateRecordsHeader, UpsertRecordsHeader as UpsertRecordsHeader, DeleteRecordUsingExternalIDParam as DeleteRecordUsingExternalIDParam, GetRecordsHeader as GetRecordsHeader, GetRecordHeader as GetRecordHeader, GetRecordUsingExternalIDParam as GetRecordUsingExternalIDParam, GetDeletedRecordsParam as GetDeletedRecordsParam, UpdateRecordUsingExternalIDHeader as UpdateRecordUsingExternalIDHeader, GetMassUpdateStatusParam as GetMassUpdateStatusParam, UpdateRecordHeader as UpdateRecordHeader, GetRecordsParam as GetRecordsParam, SearchRecordsParam as SearchRecordsParam, DeleteRecordParam as DeleteRecordParam, UpdateRecordsHeader as UpdateRecordsHeader, SearchRecordsHeader as SearchRecordsHeader, DeleteRecordHeader as DeleteRecordHeader, DeleteRecordsParam as DeleteRecordsParam, DeleteRecordsHeader as DeleteRecordsHeader, RecordOperations as MasterModel, RecordOperations as RecordOperations, RecordCountParam as RecordCountParam, GetDeletedRecordsHeader as GetDeletedRecordsHeader, DeleteRecordUsingExternalIDHeader as DeleteRecordUsingExternalIDHeader, GetRecordUsingExternalIDHeader as GetRecordUsingExternalIDHeader };
