import { Header } from "../../../../../../routes/header";
import { HeaderMap } from "../../../../../../routes/header_map";
import { Param } from "../../../../../../routes/param";
import { ParameterMap } from "../../../../../../routes/parameter_map";
import { ActionHandler } from "./action_handler";
import { BodyWrapper } from "./body_wrapper";
import { ResponseHandler } from "./response_handler";
import { APIResponse } from "../../../../../../routes/controllers/api_response";
declare class RelatedRecordsOperations {
    private moduleAPIName;
    private relatedListAPIName;
    private xExternal?;
    /**
     * Creates an instance of RelatedRecordsOperations with the given parameters
     * @param relatedListAPIName A string representing the relatedListAPIName
     * @param moduleAPIName A string representing the moduleAPIName
     * @param xExternal A string representing the xExternal
     */
    constructor(relatedListAPIName: string, moduleAPIName: string, xExternal?: string);
    /**
     * The method to get related records
     * @param recordId A bigint representing the recordId
     * @param paramInstance An instance of ParameterMap
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getRelatedRecords(recordId: bigint, paramInstance?: ParameterMap, headerInstance?: HeaderMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to update related records
     * @param recordId A bigint representing the recordId
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateRelatedRecords(recordId: bigint, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delink records
     * @param recordId A bigint representing the recordId
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    delinkRecords(recordId: bigint, paramInstance?: ParameterMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to get related records using external id
     * @param externalValue A string representing the externalValue
     * @param paramInstance An instance of ParameterMap
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getRelatedRecordsUsingExternalId(externalValue: string, paramInstance?: ParameterMap, headerInstance?: HeaderMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to update related records using external id
     * @param externalValue A string representing the externalValue
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateRelatedRecordsUsingExternalId(externalValue: string, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delete related records using external id
     * @param externalValue A string representing the externalValue
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    deleteRelatedRecordsUsingExternalId(externalValue: string, paramInstance?: ParameterMap): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to get related record
     * @param relatedRecordId A bigint representing the relatedRecordId
     * @param recordId A bigint representing the recordId
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getRelatedRecord(relatedRecordId: bigint, recordId: bigint, headerInstance?: HeaderMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to update related record
     * @param relatedRecordId A bigint representing the relatedRecordId
     * @param recordId A bigint representing the recordId
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateRelatedRecord(relatedRecordId: bigint, recordId: bigint, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delink record
     * @param relatedRecordId A bigint representing the relatedRecordId
     * @param recordId A bigint representing the recordId
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    delinkRecord(relatedRecordId: bigint, recordId: bigint): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to get related record using external id
     * @param externalFieldValue A string representing the externalFieldValue
     * @param externalValue A string representing the externalValue
     * @param headerInstance An instance of HeaderMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getRelatedRecordUsingExternalId(externalFieldValue: string, externalValue: string, headerInstance?: HeaderMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to update related record using external id
     * @param externalFieldValue A string representing the externalFieldValue
     * @param externalValue A string representing the externalValue
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateRelatedRecordUsingExternalId(externalFieldValue: string, externalValue: string, request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to delete related record using external id
     * @param externalFieldValue A string representing the externalFieldValue
     * @param externalValue A string representing the externalValue
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    deleteRelatedRecordUsingExternalId(externalFieldValue: string, externalValue: string): Promise<APIResponse<ActionHandler>>;
}
declare class GetRelatedRecordsHeader {
    static IF_MODIFIED_SINCE: Header<Date>;
}
declare class GetRelatedRecordsParam {
    static PAGE: Param<number>;
    static PER_PAGE: Param<number>;
}
declare class UpdateRelatedRecordsHeader {
}
declare class DelinkRecordsHeader {
}
declare class DelinkRecordsParam {
    static IDS: Param<string>;
}
declare class GetRelatedRecordsUsingExternalIDHeader {
    static IF_MODIFIED_SINCE: Header<Date>;
}
declare class GetRelatedRecordsUsingExternalIDParam {
    static PAGE: Param<number>;
    static PER_PAGE: Param<number>;
}
declare class UpdateRelatedRecordsUsingExternalIDHeader {
}
declare class DeleteRelatedRecordsUsingExternalIDHeader {
}
declare class DeleteRelatedRecordsUsingExternalIDParam {
    static IDS: Param<string>;
}
declare class GetRelatedRecordHeader {
    static IF_MODIFIED_SINCE: Header<Date>;
}
declare class UpdateRelatedRecordHeader {
}
declare class DelinkRecordHeader {
}
declare class GetRelatedRecordUsingExternalIDHeader {
    static IF_MODIFIED_SINCE: Header<Date>;
}
declare class UpdateRelatedRecordUsingExternalIDHeader {
}
declare class DeleteRelatedRecordUsingExternalIDHeader {
}
export { GetRelatedRecordHeader as GetRelatedRecordHeader, DelinkRecordsHeader as DelinkRecordsHeader, RelatedRecordsOperations as MasterModel, RelatedRecordsOperations as RelatedRecordsOperations, DeleteRelatedRecordUsingExternalIDHeader as DeleteRelatedRecordUsingExternalIDHeader, GetRelatedRecordsParam as GetRelatedRecordsParam, UpdateRelatedRecordUsingExternalIDHeader as UpdateRelatedRecordUsingExternalIDHeader, GetRelatedRecordsUsingExternalIDParam as GetRelatedRecordsUsingExternalIDParam, DeleteRelatedRecordsUsingExternalIDHeader as DeleteRelatedRecordsUsingExternalIDHeader, GetRelatedRecordUsingExternalIDHeader as GetRelatedRecordUsingExternalIDHeader, UpdateRelatedRecordsUsingExternalIDHeader as UpdateRelatedRecordsUsingExternalIDHeader, GetRelatedRecordsUsingExternalIDHeader as GetRelatedRecordsUsingExternalIDHeader, DeleteRelatedRecordsUsingExternalIDParam as DeleteRelatedRecordsUsingExternalIDParam, DelinkRecordHeader as DelinkRecordHeader, UpdateRelatedRecordHeader as UpdateRelatedRecordHeader, GetRelatedRecordsHeader as GetRelatedRecordsHeader, UpdateRelatedRecordsHeader as UpdateRelatedRecordsHeader, DelinkRecordsParam as DelinkRecordsParam };
