import { Param } from "../../../../../../routes/param";
import { ParameterMap } from "../../../../../../routes/parameter_map";
import { ActionHandler } from "./action_handler";
import { BodyWrapper } from "./body_wrapper";
import { DeleteActionHandler } from "./delete_action_handler";
import { ResponseHandler } from "./response_handler";
import { APIResponse } from "../../../../../../routes/controllers/api_response";
declare class ShareRecordsOperations {
    private moduleAPIName;
    private recordId;
    /**
     * Creates an instance of ShareRecordsOperations with the given parameters
     * @param recordId A bigint representing the recordId
     * @param moduleAPIName A string representing the moduleAPIName
     */
    constructor(recordId: bigint, moduleAPIName: string);
    /**
     * The method to get shared record details
     * @param paramInstance An instance of ParameterMap
     * @returns An instance of APIResponse<ResponseHandler>
     * @throws SDKException
     */
    getSharedRecordDetails(paramInstance?: ParameterMap): Promise<APIResponse<ResponseHandler>>;
    /**
     * The method to share record
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    shareRecord(request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to update share permissions
     * @param request An instance of BodyWrapper
     * @returns An instance of APIResponse<ActionHandler>
     * @throws SDKException
     */
    updateSharePermissions(request: BodyWrapper): Promise<APIResponse<ActionHandler>>;
    /**
     * The method to revoke shared record
     * @returns An instance of APIResponse<DeleteActionHandler>
     * @throws SDKException
     */
    revokeSharedRecord(): Promise<APIResponse<DeleteActionHandler>>;
}
declare class GetSharedRecordDetailsParam {
    static SHAREDTO: Param<bigint>;
    static VIEW: Param<string>;
}
export { GetSharedRecordDetailsParam as GetSharedRecordDetailsParam, ShareRecordsOperations as MasterModel, ShareRecordsOperations as ShareRecordsOperations };
