import { Token } from './token';
import { APIHTTPConnector } from '../../routes/controllers/api_http_connector';
/**
 * This class maintains the tokens and authenticates every request.
*/
export declare class OAuthToken implements Token {
    private clientID;
    private clientSecret;
    private redirectURL;
    private grantToken;
    private refreshToken;
    private accessToken;
    private expiresIn;
    private userMail;
    private id;
    /**
     * This is a setter method to set OAuth client id.
     * @param {string} clientID - A String containing the client Id.
     */
    setClientId(clientID: string): void;
    /**
     * This is a getter method to get OAuth client id.
     * @returns A String representing the OAuth client id.
    */
    getClientId(): string | null;
    /**
     * This is a setter method to set OAuth client secret.
     * @param {string} clientSecret - A String containing the client Secret.
     */
    setClientSecret(clientSecret: string): void;
    /**
     * This is a getter method to get OAuth client secret.
     * @returns A String representing the OAuth client secret.
    */
    getClientSecret(): string | null;
    /**
     * This is a setter method to set OAuth redirect URL.
     * @param {string} redirectURL - A String containing the redirectURL.
     */
    setRedirectURL(redirectURL: string | null): void;
    /**
     * This is a getter method to get OAuth redirect URL.
     * @returns A String representing the OAuth redirect URL.
    */
    getRedirectURL(): string | null;
    /**
     * This is a setter method to set grant token.
     * @param {string} grantToken - A String containing the grantToken.
     */
    setGrantToken(grantToken: string | null): void;
    /**
     * This is a getter method to get grant token.
     * @returns A String representing the grant token.
    */
    getGrantToken(): string | null;
    /**
     * This is a getter method to get refresh token.
     * @returns A String representing the refresh token.
    */
    getRefreshToken(): string | null;
    /**
     * This is a setter method to set refresh token.
     * @param {string} refreshToken - A String containing the refresh token.
    */
    setRefreshToken(refreshToken: string | null): void;
    /**
     * This is a getter method to get access token.
     * @returns A String representing the access token.
    */
    getAccessToken(): string | null;
    /**
     * This is a setter method to set access token.
     * @param {string} accessToken A String containing the access token.
    */
    setAccessToken(accessToken: string | null): void;
    /**
     * This is a getter method to get token expire time.
     * @returns A String representing the token expire time.
    */
    getExpiresIn(): string;
    /**
     * This is a setter method to set token expire time.
     * @param {string} expiresIn A String containing the token expire time.
    */
    setExpiresIn(expiresIn: string): void;
    /**
     * This is a getter method to get token user mail.
     * @returns A String representing the userMail
    */
    getUserMail(): string;
    /**
     * This is a setter method to set token user email.
     * @param {String} userMail A String containing the userMail
    */
    setUserMail(userMail: string): void;
    /**
     * This is a getter method to get the id
     * @returns the id
    */
    getId(): string | null;
    /**
     * This is a setter method to set the id
     * @param {String} id A String containing the id
    */
    setId(id: string | null): void;
    authenticate(urlConnection: APIHTTPConnector): Promise<void>;
    private refreshAccessToken;
    private generateAccessToken;
    getResponse(url: string, requestDetails: {}): Promise<import("got").Response<string>>;
    parseResponse(response: string): Promise<this>;
    getTokenExpiryTime(response: any): any;
    remove(): Promise<boolean>;
    /**
     * Creates an OAuthToken class instance with the specified parameters.
     * @param {String} clientID - A String containing the OAuth client id.
     * @param {String} clientSecret - A String containing the OAuth client secret.
     * @param {String} grantToken - A String containing the GRANT token.
     * @param {String} refreshToken - A String containing the REFRESH token.
     * @param {String} redirectURL - A String containing the OAuth redirect URL.
     * @param {String} id - A string
     */
    constructor(clientID: string | null, clientSecret: string | null, grantToken: string | null, refreshToken: string | null, redirectURL: string | null, id: string | null, accessToken: string | null);
    generateId(): Promise<void>;
}
