import { UserSignature } from "../../../routes/user_signature";
import { Token } from "../token";
import { TokenStore } from "./token_store";
/**
 * This class stores the user token details to the MySQL DataBase.
*/
export declare class DBStore implements TokenStore {
    private userName;
    private portNumber;
    private password;
    private host;
    private databaseName;
    private tableName;
    /**
     * Creates an DBStore class instance with the specified parameters.
     * @param {string} host - A String containing the DataBase host name. Default value is localhost
     * @param {string} databaseName - A String containing the DataBase name. Default value is zohooauth
     * @param {string} tableName - A String containing the DataBase table name. Default value is oauthtoken
     * @param {string} userName - A String containing the DataBase user name. Default value is root
     * @param {string} password - A String containing the DataBase password. Default value is an empty string
     * @param {string} portNumber - A String containing the DataBase port number. Default value is 3306
     */
    constructor(host: string, databaseName: string, tableName: string, userName: string, password: string, portNumber: number);
    getToken(user: UserSignature, token: Token): Promise<Token | undefined>;
    saveToken(user: UserSignature, token: Token): Promise<void>;
    deleteToken(token: Token): Promise<void>;
    getTokens(): Promise<Array<Token> | undefined>;
    deleteTokens(): Promise<void>;
    private constructDBQuery;
    private getConnection;
    getTokenById(id: string, token: Token): Promise<Token | undefined>;
}
